@@ -1,5 +1,12 @@
+# -*- coding: utf-8 -*-
+#
+# Copyright (c) 2021, CloudBlue
+# All rights reserved.
+#
+
 from datetime import datetime
 from threading import Lock
+import collections
 
 
 def convert_to_datetime(param_value):
@@ -12,6 +19,10 @@ def convert_to_datetime(param_value):
     )
 
 
+def today_str():
+    return datetime.today().strftime('%Y-%m-%d %H:%M:%S')
+
+
 def get_basic_value(base, value):
     if base and value in base:
         return base[value]
@@ -25,7 +36,6 @@ def get_value(base, prop, value):
 
 
 class Progress:
-
     def __init__(self, callback, total):
         self.lock = Lock()
         self.current = 0
@@ -37,3 +47,12 @@ class Progress:
         self.current += 1
         self.callback(self.current, self.total)
         self.lock.release()
+
+
+def get_dict_element(dictionary, *keys):
+    if not keys or keys[0] not in dictionary:
+        if not dictionary or isinstance(dictionary, collections.Mapping):
+            return ''
+        return dictionary
+    key = keys[0]
+    return get_dict_element(dictionary[key], *keys[1:])
